Macro anchor_macro::klipper_static_string
source · klipper_static_string!() { /* proc-macro */ }Expand description
Adds a static string to the generated protocol dictionary
This directly adds a static string to the static_string_id dictionary. The returned value
will be the ID of the added string.
This compile to a constant value.